@@ -3,7 +3,7 @@ use warnings;
 
 package Net::FreshBooks::API::Error;
 BEGIN {
-  $Net::FreshBooks::API::Error::VERSION = '0.19';
+  $Net::FreshBooks::API::Error::VERSION = '0.20';
 }
 
 use Moose;
@@ -30,17 +30,19 @@ sub handle_server_error {
 
 1;
 
+# ABSTRACT: FreshBooks error handling (experimental)
+
 
 __END__
 =pod
 
 =head1 NAME
 
-Net::FreshBooks::API::Error
+Net::FreshBooks::API::Error - FreshBooks error handling (experimental)
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
