@@ -3,7 +3,7 @@ use warnings;
 
 package Net::FreshBooks::API::Links;
 BEGIN {
-  $Net::FreshBooks::API::Links::VERSION = '0.19';
+  $Net::FreshBooks::API::Links::VERSION = '0.20';
 }
 
 use Moose;
@@ -24,17 +24,19 @@ __PACKAGE__->meta->make_immutable();
 
 1;
 
+# ABSTRACT: Provides FreshBooks Link objects to Clients and Invoices
+
 
 __END__
 =pod
 
 =head1 NAME
 
-Net::FreshBooks::API::Links
+Net::FreshBooks::API::Links - Provides FreshBooks Link objects to Clients and Invoices
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
